# Changelog


## [0.2.0] - 2023-04-10
### Added
- attribute base16_colorlib.\_\_version\_\_
- ability to import modules (color_scheme.py utils.py)

### Changed
- renamed module color.py to utils.py (backward compatibility preserved)

## [0.1.0] - 2023-04-09
### Added
- 35 color schemes
- class Color
